# Yacce Changelog

## 0.9.10
- default value for `bazel --external` option is set to `combine-all` as this
gives the most visibility into a project internals.

## 0.9.9
- about the first announced release of yacce.